=======
History
=======

0.0.1 (27.04.2019.)
-------------------

* First release on PyPI.

0.0.2 (21.07.2020.)
-------------------

* Trefle.io changed so this release retains links to an old version that is to be removed.
